package Net::DNS::RR::GPOS;

use strict;
use warnings;
our $VERSION = (qw$Id: GPOS.pm 1910 2023-03-30 19:16:30Z willem $)[2];

use base qw(Net::DNS::RR);



use integer;

use Carp;
use Net::DNS::Text;


sub _decode_rdata {			## decode rdata from wire-format octet string
	my ( $self, $data, $offset ) = @_;

	my $limit = $offset + $self->{rdlength};
	for (qw(latitude longitude altitude)) {
		my $text;
		( $text, $offset ) = Net::DNS::Text->decode( $data, $offset );
		$self->$_( $text->value );
	}
	croak('corrupt GPOS data') unless $offset == $limit;	# more or less FUBAR
	return;
}


sub _encode_rdata {			## encode rdata as wire-format octet string
	my $self = shift;

	return join '', map { Net::DNS::Text->new($_)->encode } @{$self}{qw(latitude longitude altitude)};
}


sub _format_rdata {			## format rdata portion of RR string.
	my $self = shift;

	return map { Net::DNS::Text->new($_)->string } @{$self}{qw(latitude longitude altitude)};
}


sub _parse_rdata {			## populate RR from rdata in argument list
	my ( $self, @argument ) = @_;

	$self->latitude( shift @argument );
	$self->longitude( shift @argument );
	$self->altitude(@argument);
	return;
}


sub _defaults {				## specify RR attribute default values
	my $self = shift;

	$self->_parse_rdata(qw(0.0 0.0 0.0));
	return;
}


sub latitude {
	my ( $self, @value ) = @_;
	for (@value) { return $self->{latitude} = _fp($_) }
	return $self->{latitude};
}


sub longitude {
	my ( $self, @value ) = @_;
	for (@value) { return $self->{longitude} = _fp($_) }
	return $self->{longitude};
}


sub altitude {
	my ( $self, @value ) = @_;
	for (@value) { return $self->{altitude} = _fp($_) }
	return $self->{altitude};
}



sub _fp {
	no integer;
	return sprintf( '%1.10g', 0.0 + shift );
}



1;
__END__


